@@ -67,7 +67,9 @@ def fetch_relational_data(
                 function_result = method(**func.get('params'))
 
                 fields = func.get('fields')
-                if function_result:
+                if not fields:
+                    relational_data_result = function_result
+                elif function_result:
                     if isinstance(function_result, list):
                         for row in function_result:
                             _update_relational_data_result(row, fields)
