@@ -120,6 +120,10 @@ def from_string_to_datetime(value, value_format=DATABASE_DATE_TIME_FORMAT):
     return datetime.strptime(value, value_format)
 
 
+def from_string_to_date(value, value_format=DATABASE_DATE_FORMAT):
+    return from_string_to_datetime(value, value_format).date()
+
+
 def from_datetime_to_string(value):
     return str(value)
 
@@ -136,3 +140,10 @@ def from_bulk_string_to_datetime(value_list, keys, value_format=DATABASE_DATE_TI
         for key in keys:
             item[key] = from_string_to_datetime(value=item[key], value_format=value_format)
     return value_list
+
+
+def from_bulk_string_to_date(value_list, keys, value_format=DATABASE_DATE_FORMAT):
+    for item in value_list:
+        for key in keys:
+            item[key] = from_string_to_date(value=item[key], value_format=value_format)
+    return value_list
